Installation
============

Stable
------

Get `cellregulondb from PyPI`_ (consider using `pip3` to access Python 3):

    .. code-block:: bash

        pip install cellregulon



Dev version
-----------

Use pip to install directly from GitHub:

    .. code-block:: bash

        pip install git+https://github.com/Teichlab/cellregulondb.git


.. _`cellregulondb from PyPI`: https://pypi.org/project/cellregulondb
